function Tone = LStones(Ffreq,Dur,SR)

% function LStones(Ffreq,Dur,SR)
%
% Tone generator written on February 18, 2010 for duration deviant paradigm
% for HCS Prototype. Modified on November 29, 2010 for use in the normal
% pattern deviant version of the HCS stimulus sequence.

% Takes input in the form of fundamental tone frequency (Ffreq), duration 
% (Dur), and rise/fall time (RF). All times are specified in seconds. 
% Generates a complex tone with 2 harmonics. Outputs this tone as a vector 
% to be used for stimulus presentation.

Har1 = Ffreq*2;  % Frequency of the first harmonic.
Har2 = Ffreq*3;  % Frequency of the second harmonic.

RF = 0.0025;
% Defines rise/fall time to be 5 ms (2.5 ms rise, 2.5 ms fall).

n = 0:(ceil(SR*Dur)-1);
% Create a vector of values that increment sequentially by 1 from 0 to the 
% number of samples in the sound.

Tone = sin(2*pi*Ffreq/SR*n) + exp(-1)*sin(2*pi*Har1/SR*n) + exp(-2)*sin(2*pi*Har2/SR*n);
% Generate the complex tone without rise/fall time. The harmonics are
% subject to exponential decay (e^-1 for the first harmonic, e^-2 for the
% second harmonic).

if RF > 0
    
    RFSamples = ceil(RF * SR);
    % Calculates the number of samples included in the rise or fall time, 
    % rounded up.

    Ramp = linspace(0,1,RFSamples);
    % Generates values between 0 and 1, one value for each of the samples in
    % the rise or fall time. These will be the values for the intensity ramp.

    for j = 1:length(Ramp)
        Tone(j) = Tone(j) * Ramp(j);
        Tone(length(Tone) + 1 - j) = Tone(length(Tone) + 1 - j)*Ramp(j);
    end
    % Cycle through the tone for the number of samples that encompass the rise
    % time, multiplying the intensity at each point by the Ramp. Points of equal 
    % intensity are created at the beginning and ending of the tone in order to
    % create both the rise and the fall.
end
